<?php
/*
Plugin Name: FitGirl Killer By WooPlug.store
Plugin URI: https://wooplug.store
Description: This plugin allows you to scrape content from FitGirl Repacks website and create WordPress posts with game information, images, and download links.
Version: 2.0
Author: WooPlug.store
Author URI: https://wooplug.store
License: GPLv2 or later
*/

// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Plugin constants
define('FITGIRL_KILLER_VERSION', '2.0');
define('FITGIRL_KILLER_PATH', plugin_dir_path(__FILE__));
define('FITGIRL_KILLER_URL', plugin_dir_url(__FILE__));

// Autoload classes
spl_autoload_register(function ($class) {
    $prefix = 'FitGirlKiller\\';
    $base_dir = FITGIRL_KILLER_PATH . 'includes/';

    $len = strlen($prefix);
    if (strncmp($prefix, $class, $len) !== 0) {
        return;
    }

    $relative_class = substr($class, $len);
    $file = $base_dir . str_replace('\\', '/', $relative_class) . '.php';

    if (file_exists($file)) {
        require $file;
    }
});

// Initialize plugin
function fitgirl_killer_init() {
    // Load required files
    require_once FITGIRL_KILLER_PATH . 'includes/class-scraper.php';
    require_once FITGIRL_KILLER_PATH . 'includes/class-poster.php';
    require_once FITGIRL_KILLER_PATH . 'includes/class-admin.php';
    
    // Initialize admin
    new FitGirlKiller\Admin();
}
add_action('plugins_loaded', 'fitgirl_killer_init');

// Enqueue public styles
function fitgirl_killer_public_enqueue() {
    wp_enqueue_style(
        'fitgirl-killer-public',
        FITGIRL_KILLER_URL . 'assets/css/public.css',
        [],
        FITGIRL_KILLER_VERSION
    );
}
add_action('wp_enqueue_scripts', 'fitgirl_killer_public_enqueue');

// Enqueue admin scripts and styles
function fitgirl_killer_admin_enqueue($hook) {
    if ('toplevel_page_fitgirl-killer' !== $hook) {
        return;
    }

    wp_enqueue_style(
        'fitgirl-killer-admin',
        FITGIRL_KILLER_URL . 'assets/css/admin.css',
        [],
        FITGIRL_KILLER_VERSION
    );

    wp_enqueue_script(
        'fitgirl-killer-admin',
        FITGIRL_KILLER_URL . 'assets/js/admin.js',
        ['jquery'],
        FITGIRL_KILLER_VERSION,
        true
    );

    wp_localize_script('fitgirl-killer-admin', 'fitgirlKillerAdmin', [
        'ajaxUrl' => admin_url('admin-ajax.php'),
        'nonce' => wp_create_nonce('fitgirl-killer-admin-nonce')
    ]);
}
add_action('admin_enqueue_scripts', 'fitgirl_killer_admin_enqueue');

// Register activation hook
function fitgirl_killer_activate() {
    // Create necessary directories
    $upload_dir = wp_upload_dir();
    $killer_dir = $upload_dir['basedir'] . '/fitgirl-killer';
    
    if (!file_exists($killer_dir)) {
        wp_mkdir_p($killer_dir);
    }
}
register_activation_hook(__FILE__, 'fitgirl_killer_activate');
