jQuery(document).ready(function($) {
    const form = $('#fitgirl-killer-form');
    const previewCard = $('#preview-card');
    const notification = $('#notification');
    const scrapeButton = $('.scrape-button');
    
    // Form submission
    form.on('submit', function(e) {
        e.preventDefault();
        
        const url = $('#url').val();
        
        // Validate FitGirl URL
        if (!url.includes('fitgirl-repacks.site')) {
            showNotification('error', 'Invalid URL. Please enter a valid FitGirl Repacks URL.');
            return;
        }
        
        // Show loading state
        scrapeButton.addClass('loading');
        
        // Make AJAX request
        $.ajax({
            url: fitgirlKillerAdmin.ajaxUrl,
            type: 'POST',
            data: {
                action: 'fitgirl_killer_scrape_url',
                nonce: fitgirlKillerAdmin.nonce,
                url: url,
                categories: $('#categories').val()
            },
            success: function(response) {
                if (response.success) {
                    showNotification('success', `Post created successfully! <a href="${response.data.post_url}" target="_blank">View "${response.data.post_title}"</a>`);
                    form[0].reset();
                } else {
                    showNotification('error', response.data.message || 'An error occurred');
                }
            },
            error: function(xhr, status, error) {
                showNotification('error', 'An error occurred. Please try again.');
            },
            complete: function() {
                scrapeButton.removeClass('loading');
            }
        });
    });
    
    // Show notification
    function showNotification(type, message) {
        const notificationEl = notification;
        const messageEl = notificationEl.find('.notification-message');
        
        // Set message and type
        messageEl.html(message);
        notificationEl.removeClass('success error').addClass(type);
        
        // Show notification
        notificationEl.removeClass('hidden').addClass('visible');
        
        // Auto-hide after 5 seconds
        setTimeout(() => {
            notificationEl.removeClass('visible');
            setTimeout(() => notificationEl.addClass('hidden'), 300);
        }, 5000);
    }
    
    // Close notification
    $('.close-notification').on('click', function() {
        notification.removeClass('visible');
        setTimeout(() => notification.addClass('hidden'), 300);
    });
    
    // Close preview
    $('.close-preview').on('click', function() {
        previewCard.removeClass('visible');
    });
    
    // Copy donation details on click
    $('.donation-id, .donation-address').on('click', function() {
        const text = $(this).text();
        navigator.clipboard.writeText(text).then(() => {
            showNotification('success', 'Copied to clipboard!');
        });
    });
});