<?php
namespace FitGirlKiller;

class Admin {
    public function __construct() {
        add_action('admin_menu', [$this, 'add_menu_page']);
        add_action('wp_ajax_fitgirl_killer_scrape_url', [$this, 'handle_ajax_scrape']);
    }

    public function add_menu_page() {
        add_menu_page(
            'FitGirl-Killer-By-WooPlug',
            'FitGirl-Killer-By-WooPlug',
            'manage_options',
            'fitgirl-killer',
            [$this, 'render_admin_page'],
            'dashicons-games',
            30
        );
    }

    public function render_admin_page() {
        ?>
        <div class="wrap fitgirl-killer-admin">
            <div class="admin-header">
                <h1>FitGirl-Killer-By-WooPlug</h1>
                <div class="header-meta">
                    <span class="version">Version <?php echo FITGIRL_KILLER_VERSION; ?></span>
                </div>
            </div>

            <div class="admin-content">
                <div class="scraper-card">
                    <div class="card-header">
                        <h2>Scrape New Game</h2>
                        <p>Enter a FitGirl Repack URL to scrape and create a new post.</p>
                    </div>

                    <form id="fitgirl-killer-form" class="card-content">
                        <div class="form-group">
                            <label for="url">Game URL</label>
                            <input type="url" 
                                   id="url" 
                                   name="url" 
                                   placeholder="https://fitgirl-repacks.site/game-name/"
                                   required>
                        </div>

                        <div class="form-group">
                            <label for="categories">Categories</label>
                            <input type="text" 
                                   id="categories" 
                                   name="categories" 
                                   placeholder="Enter categories separated by commas">
                            <small>Example: Games, Action, RPG</small>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="button-primary scrape-button">
                                <span class="button-content">
                                    <span class="dashicons dashicons-download"></span>
                                    Scrape and Create Post
                                </span>
                                <span class="loading-spinner"></span>
                            </button>
                        </div>
                    </form>
                </div>

                <div class="donation-card">
                    <div class="card-header">
                        <h2>Support the Developer</h2>
                        <p>If you find this plugin helpful, consider supporting its development!</p>
                    </div>
                    <div class="card-content">
                        <div class="donation-options">
                            <div class="donation-option">
                                <h3><span class="dashicons dashicons-paypal"></span> PayPal</h3>
                                <a href="https://www.paypal.com/paypalme/ramflow" target="_blank" class="button-secondary">
                                    Donate via PayPal
                                </a>
                            </div>
                            <div class="donation-option">
                                <h3><span class="dashicons dashicons-money-alt"></span> Binance</h3>
                                <p class="donation-id">ID: 290696706</p>
                            </div>
                            <div class="donation-option">
                                <h3><span class="dashicons dashicons-money-alt"></span> USDT (TRC20)</h3>
                                <p class="donation-address">TB4MYsGMSJnTqJzjZYz9HzS4183bPqCGCe</p>
                            </div>
                        </div>
                    </div>
                </div>

                <div id="preview-card" class="preview-card hidden">
                    <div class="card-header">
                        <h2>Preview</h2>
                        <button class="close-preview">×</button>
                    </div>
                    <div class="card-content">
                        <div class="preview-content"></div>
                        <div class="preview-actions">
                            <button class="button-primary publish-button">
                                <span class="dashicons dashicons-yes"></span>
                                Publish Post
                            </button>
                            <button class="button-secondary edit-button">
                                <span class="dashicons dashicons-edit"></span>
                                Edit
                            </button>
                        </div>
                    </div>
                </div>
            </div>

            <div id="notification" class="notification hidden">
                <div class="notification-content">
                    <span class="notification-message"></span>
                    <button class="close-notification">×</button>
                </div>
            </div>
        </div>
        <?php
    }

    public function handle_ajax_scrape() {
        check_ajax_referer('fitgirl-killer-admin-nonce', 'nonce');

        if (!current_user_can('manage_options')) {
            wp_send_json_error([
                'title' => 'Permission Denied',
                'message' => 'You do not have sufficient permissions to perform this action.',
                'type' => 'error'
            ]);
            return;
        }

        $url = sanitize_url($_POST['url']);
        
        // Check if URL is from fitgirl-repacks.site
        if (strpos($url, 'fitgirl-repacks.site') === false) {
            wp_send_json_error([
                'title' => 'Invalid URL',
                'message' => 'Please enter a valid FitGirl Repacks URL. The URL must be from fitgirl-repacks.site',
                'type' => 'error'
            ]);
            return;
        }

        try {
            $scraper = new Scraper($url);
            $data = $scraper->scrape();

            if (empty($data)) {
                throw new \Exception('No data was found on the provided URL. Please verify the URL and try again.');
            }

            $categories = !empty($_POST['categories']) ? 
                array_map('sanitize_text_field', explode(',', $_POST['categories'])) : 
                [];

            $poster = new Poster($data, $categories);
            $result = $poster->create_post();

            if ($result['success']) {
                wp_send_json_success([
                    'title' => 'Post Created Successfully',
                    'message' => sprintf(
                        'The post has been created successfully! <a href="%s">View Post</a>',
                        esc_url(get_permalink($result['post_id']))
                    ),
                    'type' => 'success',
                    'post_url' => get_permalink($result['post_id']),
                    'post_title' => get_the_title($result['post_id'])
                ]);
            } else {
                wp_send_json_error([
                    'title' => 'Post Creation Failed',
                    'message' => 'Failed to create the post. ' . $result['error'],
                    'type' => 'error',
                    'details' => $result['error']
                ]);
            }

        } catch (\Exception $e) {
            $error_message = $e->getMessage();
            $user_message = 'An error occurred while processing your request.';
            
            // Common error cases
            $error_cases = [
                'cURL error 28' => 'Connection timed out. The website might be down or responding slowly.',
                'cURL error 6' => 'Could not resolve host. Please check your internet connection.',
                '404' => 'The page was not found. Please verify the URL.',
                'SSL certificate' => 'SSL certificate verification failed. The website might be having security issues.',
                'No data was found' => 'No game data was found on the provided URL. Please verify the URL.',
                'Permission denied' => 'WordPress cannot write to the uploads directory. Please check folder permissions.'
            ];

            foreach ($error_cases as $error_type => $message) {
                if (stripos($error_message, $error_type) !== false) {
                    $user_message = $message;
                    break;
                }
            }

            wp_send_json_error([
                'title' => 'Error',
                'message' => $user_message,
                'type' => 'error',
                'details' => $error_message
            ]);
        }
    }
}